ete2.treeview.drawer._SelectorItem

Package ete2 :: Package treeview :: Module drawer :: Class _SelectorItem |
[hide private]
[frames] | no frames]

# Class _SelectorItem

source code

                    object --+
                             |
             sip.simplewrapper --+
                                 |
                       sip.wrapper --+
                                     |
             PyQt4.QtGui.QGraphicsItem --+
                                         |
    PyQt4.QtGui.QAbstractGraphicsShapeItem --+
                                             |
                 PyQt4.QtGui.QGraphicsRectItem --+
                                                 |
                                                _SelectorItem

Nested Classes | [hide private]
Inherited from `PyQt4.QtGui.QGraphicsItem`: `CacheMode`, `GraphicsItemChange`, `GraphicsItemFlag`, `GraphicsItemFlags`

Instance Methods | [hide private]
__init__(self) x.__init__(...) initializes x; see x.__class__.__doc__ for signature | source code
paint(self, p, option, widget) | source code
get_selected_nodes(self) | source code
setActive(self, bool) | source code
isActive(self) | source code
Inherited from `PyQt4.QtGui.QGraphicsRectItem`: `boundingRect`, `contains`, `contextMenuEvent`, `dragEnterEvent`, `dragLeaveEvent`, `dragMoveEvent`, `dropEvent`, `focusInEvent`, `focusOutEvent`, `hoverEnterEvent`, `hoverLeaveEvent`, `hoverMoveEvent`, `inputMethodEvent`, `inputMethodQuery`, `isObscuredBy`, `itemChange`, `keyPressEvent`, `keyReleaseEvent`, `mouseDoubleClickEvent`, `mouseMoveEvent`, `mousePressEvent`, `mouseReleaseEvent`, `opaqueArea`, `prepareGeometryChange`, `rect`, `sceneEvent`, `sceneEventFilter`, `setRect`, `shape`, `type`, `wheelEvent` Inherited from `PyQt4.QtGui.QAbstractGraphicsShapeItem`: `brush`, `pen`, `setBrush`, `setPen` Inherited from `PyQt4.QtGui.QGraphicsItem`: `acceptDrops`, `acceptHoverEvents`, `acceptedMouseButtons`, `acceptsHoverEvents`, `advance`, `boundingRegion`, `boundingRegionGranularity`, `cacheMode`, `childItems`, `children`, `childrenBoundingRect`, `clearFocus`, `clipPath`, `collidesWithItem`, `collidesWithPath`, `collidingItems`, `commonAncestorItem`, `cursor`, `data`, `deviceTransform`, `effectiveOpacity`, `ensureVisible`, `flags`, `grabKeyboard`, `grabMouse`, `group`, `handlesChildEvents`, `hasCursor`, `hasFocus`, `hide`, `installSceneEventFilter`, `isAncestorOf`, `isClipped`, `isEnabled`, `isObscured`, `isSelected`, `isUnderMouse`, `isVisible`, `isVisibleTo`, `isWidget`, `isWindow`, `itemTransform`, `mapFromItem`, `mapFromParent`, `mapFromScene`, `mapRectFromItem`, `mapRectFromParent`, `mapRectFromScene`, `mapRectToItem`, `mapRectToParent`, `mapRectToScene`, `mapToItem`, `mapToParent`, `mapToScene`, `matrix`, `moveBy`, `opacity`, `parentItem`, `parentWidget`, `pos`, `removeSceneEventFilter`, `resetMatrix`, `resetTransform`, `rotate`, `scale`, `scene`, `sceneBoundingRect`, `sceneMatrix`, `scenePos`, `sceneTransform`, `scroll`, `setAcceptDrops`, `setAcceptHoverEvents`, `setAcceptedMouseButtons`, `setAcceptsHoverEvents`, `setBoundingRegionGranularity`, `setCacheMode`, `setCursor`, `setData`, `setEnabled`, `setFlag`, `setFlags`, `setFocus`, `setGroup`, `setHandlesChildEvents`, `setMatrix`, `setOpacity`, `setParentItem`, `setPos`, `setSelected`, `setToolTip`, `setTransform`, `setVisible`, `setZValue`, `shear`, `show`, `toolTip`, `topLevelItem`, `topLevelWidget`, `transform`, `translate`, `ungrabKeyboard`, `ungrabMouse`, `unsetCursor`, `update`, `window`, `x`, `y`, `zValue` Inherited from `sip.simplewrapper`: `__delattr__`, `__getattribute__`, `__new__`, `__setattr__` Inherited from `object`: `__format__`, `__hash__`, `__reduce__`, `__reduce_ex__`, `__repr__`, `__sizeof__`, `__str__`, `__subclasshook__`

Class Variables | [hide private]
Inherited from `PyQt4.QtGui.QGraphicsItem`: `DeviceCoordinateCache`, `ItemChildAddedChange`, `ItemChildRemovedChange`, `ItemClipsChildrenToShape`, `ItemClipsToShape`, `ItemCoordinateCache`, `ItemCursorChange`, `ItemCursorHasChanged`, `ItemDoesntPropagateOpacityToChildren`, `ItemEnabledChange`, `ItemEnabledHasChanged`, `ItemFlagsChange`, `ItemFlagsHaveChanged`, `ItemIgnoresParentOpacity`, `ItemIgnoresTransformations`, `ItemIsFocusable`, `ItemIsMovable`, `ItemIsSelectable`, `ItemMatrixChange`, `ItemOpacityChange`, `ItemOpacityHasChanged`, `ItemParentChange`, `ItemParentHasChanged`, `ItemPositionChange`, `ItemPositionHasChanged`, `ItemSceneChange`, `ItemSceneHasChanged`, `ItemSelectedChange`, `ItemSelectedHasChanged`, `ItemStacksBehindParent`, `ItemToolTipChange`, `ItemToolTipHasChanged`, `ItemTransformChange`, `ItemTransformHasChanged`, `ItemVisibleChange`, `ItemVisibleHasChanged`, `ItemZValueChange`, `ItemZValueHasChanged`, `NoCache`, `UserType`

Properties | [hide private]
Inherited from `object`: `__class__`

Method Details | [hide private]

### __init__(self) (Constructor) | source code
x.__init__(...) initializes x; see x.__class__.__doc__ for signature Overrides: object.__init__ (inherited documentation)

### paint(self, p, option, widget) | source code
Overrides: PyQt4.QtGui.QGraphicsItem.paint